using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace Pybrary.Plot.Demo
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            standardMenuStrip.Items.Add(standardPlotControl.CreatePlotMenu());
            manyMenuStrip.Items.Add(manyPlotControl.CreatePlotMenu());
            dateMenuStrip.Items.Add(datePlotControl.CreatePlotMenu());
            stackedMenuStrip.Items.Add(stackedPlotControl.CreatePlotMenu());

            InitializeStandardPlot();
            InitializeManyPlot();
            InitializeDatePlot();
            InitializeStackedPlot();
        }

        private void InitializeStandardPlot()
        {
            Plot p = new Plot();
            p.UseNumericXAxis();
            p.HeaderCenter = "Body Mass Index";
            p.DisplayLegend = true;

            ((NumericXAxis)p.XAxis).Title = "Weight (kg)";
            p.YAxes["Default"].Title = "Height (m)";

            ScatterSeries series = CreateBmiSeries(18.5);
            series.Line.Color = Color.GreenYellow;
            p.Series["Underweight"] = series;

            series = CreateBmiSeries(21.75);
            series.Line.Color = Color.Green;
            p.Series["Ideal"] = series;

            series = CreateBmiSeries(27.5);
            series.Line.Color = Color.Orange;
            p.Series["Overweight"] = series;

            series = CreateBmiSeries(30);
            series.Line.Color = Color.Red;
            p.Series["Obese"] = series;

            standardPlotControl.Plot = p;
        }

        private ScatterSeries CreateBmiSeries(double bmi)
        {
            ScatterSeries series = new ScatterSeries();
            IList<double> x = new List<double>();
            IList<double> y = new List<double>();
            for (double height = 0; height < 2.25; height += 0.1)
            {
                double weight = bmi * (height * height);
                x.Add(weight);
                y.Add(height);
            }
            series.Data.Set(x, y);
            return series;
        }

        private void InitializeManyPlot()
        {
            Plot p = new Plot();
            p.UseNumericXAxis();

            ((NumericXAxis)p.XAxis).Title = "x (degrees)";

            p.YAxes["Default"].Title = "sin[x]";
            ScatterSeries series = new ScatterSeries();
            series.YAxisName = "Default";
            List<double> xArr = new List<double>();
            List<double> yArr = new List<double>();
            for (double x = 0; x < 360; x++)
            {
                xArr.Add(x);
                yArr.Add(Math.Sin(x * Math.PI / 180));
            }
            series.Data.Set(xArr, yArr);
            p.Series["sin[x]"] = series;

            p.YAxes.AddLeft("cos[x]");
            p.YAxes["cos[x]"].Title = "cos[x]";
            p.YAxes["cos[x]"].GridlinesEnabled = false;
            series = new ScatterSeries();
            series.Line.Color = Color.Green;
            series.YAxisName = "cos[x]";
            xArr = new List<double>();
            yArr = new List<double>();
            for (double x = 0; x < 360; x++)
            {
                xArr.Add(x);
                yArr.Add(Math.Cos(x * Math.PI / 180));
            }
            series.Data.Set(xArr, yArr);
            p.Series["cos[x]"] = series;

            p.YAxes.AddRight("tan[x]");
            p.YAxes["tan[x]"].Title = "tan[x]";
            p.YAxes["tan[x]"].GridlinesEnabled = false;
            series = new ScatterSeries();
            series.Line.Color = Color.Red;
            series.YAxisName = "tan[x]";
            xArr = new List<double>();
            yArr = new List<double>();
            for (double x = 0; x < 360; x++)
            {
                double y = Math.Tan(x * Math.PI / 180);
                if (Double.IsInfinity(y) || Double.IsNaN(y) || y > 1e5 || y < -1e5)
                    continue;
                xArr.Add(x);
                yArr.Add(y);
            }
            series.Data.Set(xArr, yArr);
            p.Series["tan[x]"] = series;

            manyPlotControl.Plot = p;
        }

        private void InitializeDatePlot()
        {
            Plot p = new Plot();
            p.HeaderCenter = "Stock Price Comparison";
            p.HeaderRight = "Apple vs. Microsoft";
            p.DisplayLegend = true;

            p.YAxes["Default"].Title = "Apple (USD)";
            p.YAxes["Default"].GridlinesEnabled = false;
            ScatterSeries series = new ScatterSeries();
            series.Data.Set(dates, apple_prices);
            p.Series["Apple"] = series;

            p.YAxes.AddRight("MSFT");
            p.YAxes["MSFT"].Title = "Microsoft (USD)";
            p.YAxes["MSFT"].GridlinesEnabled = false;
            series = new ScatterSeries();
            series.YAxisName = "MSFT";
            series.Line.Color = Color.Red;
            series.Data.Set(dates, msft_prices);
            p.Series["Microsoft"] = series;

            datePlotControl.Plot = p;
        }

        private void InitializeStackedPlot()
        {
            Plot p = new Plot();
            p.DisplayLegend = true;

            p.HeaderCenter = "Stock Volume Comparison";
            p.HeaderRight = "Apple vs. Microsoft";
            p.YAxes["Default"].Title = "Share Volume";

            StackedSeries series = new StackedSeries();
            series.Brushes.Add(new BrushDescription(Color.FromArgb(128, Color.Blue)));
            series.Brushes.Add(new BrushDescription(Color.FromArgb(128, Color.Red)));
            series.Pens.Add(new PenDescription(Color.Black, 1f / 96));
            series.Data.Set(dates, new IList<double?>[] { new List<double?>(apple_volume), new List<double?>(msft_volume) });
            series.DatasetNames.Add("Apple");
            series.DatasetNames.Add("Microsoft");
            p.Series["Data"] = series;

            stackedPlotControl.Plot = p;
        }

        private DateTime[] dates = new DateTime[] {
            new DateTime(	2006	,	11	,	24	),
            new DateTime(	2006	,	11	,	22	),
            new DateTime(	2006	,	11	,	21	),
            new DateTime(	2006	,	11	,	20	),
            new DateTime(	2006	,	11	,	17	),
            new DateTime(	2006	,	11	,	16	),
            new DateTime(	2006	,	11	,	15	),
            new DateTime(	2006	,	11	,	14	),
            new DateTime(	2006	,	11	,	13	),
            new DateTime(	2006	,	11	,	10	),
            new DateTime(	2006	,	11	,	9	),
            new DateTime(	2006	,	11	,	8	),
            new DateTime(	2006	,	11	,	7	),
            new DateTime(	2006	,	11	,	6	),
            new DateTime(	2006	,	11	,	3	),
            new DateTime(	2006	,	11	,	2	),
            new DateTime(	2006	,	11	,	1	),
            new DateTime(	2006	,	10	,	31	),
            new DateTime(	2006	,	10	,	30	),
            new DateTime(	2006	,	10	,	27	),
            new DateTime(	2006	,	10	,	26	),
            new DateTime(	2006	,	10	,	25	),
            new DateTime(	2006	,	10	,	24	),
            new DateTime(	2006	,	10	,	23	),
            new DateTime(	2006	,	10	,	20	),
            new DateTime(	2006	,	10	,	19	),
            new DateTime(	2006	,	10	,	18	),
            new DateTime(	2006	,	10	,	17	),
            new DateTime(	2006	,	10	,	16	),
            new DateTime(	2006	,	10	,	13	),
            new DateTime(	2006	,	10	,	12	),
            new DateTime(	2006	,	10	,	11	),
            new DateTime(	2006	,	10	,	10	),
            new DateTime(	2006	,	10	,	9	),
            new DateTime(	2006	,	10	,	6	),
            new DateTime(	2006	,	10	,	5	),
            new DateTime(	2006	,	10	,	4	),
            new DateTime(	2006	,	10	,	3	),
            new DateTime(	2006	,	10	,	2	),
            new DateTime(	2006	,	9	,	29	),
            new DateTime(	2006	,	9	,	28	),
            new DateTime(	2006	,	9	,	27	),
            new DateTime(	2006	,	9	,	26	),
            new DateTime(	2006	,	9	,	25	),
            new DateTime(	2006	,	9	,	22	),
            new DateTime(	2006	,	9	,	21	),
            new DateTime(	2006	,	9	,	20	),
            new DateTime(	2006	,	9	,	19	),
            new DateTime(	2006	,	9	,	18	),
            new DateTime(	2006	,	9	,	15	),
            new DateTime(	2006	,	9	,	14	),
            new DateTime(	2006	,	9	,	13	),
            new DateTime(	2006	,	9	,	12	),
            new DateTime(	2006	,	9	,	11	),
            new DateTime(	2006	,	9	,	8	),
            new DateTime(	2006	,	9	,	7	),
            new DateTime(	2006	,	9	,	6	),
            new DateTime(	2006	,	9	,	5	),
            new DateTime(	2006	,	9	,	1	),
            new DateTime(	2006	,	8	,	31	),
            new DateTime(	2006	,	8	,	30	),
            new DateTime(	2006	,	8	,	29	),
            new DateTime(	2006	,	8	,	28	),
            new DateTime(	2006	,	8	,	25	),
            new DateTime(	2006	,	8	,	24	),
            new DateTime(	2006	,	8	,	23	),
            new DateTime(	2006	,	8	,	22	),
            new DateTime(	2006	,	8	,	21	),
            new DateTime(	2006	,	8	,	18	),
            new DateTime(	2006	,	8	,	17	),
            new DateTime(	2006	,	8	,	16	),
            new DateTime(	2006	,	8	,	15	),
            new DateTime(	2006	,	8	,	14	),
            new DateTime(	2006	,	8	,	11	),
            new DateTime(	2006	,	8	,	10	),
            new DateTime(	2006	,	8	,	9	),
            new DateTime(	2006	,	8	,	8	),
            new DateTime(	2006	,	8	,	7	),
            new DateTime(	2006	,	8	,	4	),
            new DateTime(	2006	,	8	,	3	),
            new DateTime(	2006	,	8	,	2	),
            new DateTime(	2006	,	8	,	1	),
            new DateTime(	2006	,	7	,	31	),
            new DateTime(	2006	,	7	,	28	),
            new DateTime(	2006	,	7	,	27	),
            new DateTime(	2006	,	7	,	26	),
            new DateTime(	2006	,	7	,	25	),
            new DateTime(	2006	,	7	,	24	),
            new DateTime(	2006	,	7	,	21	),
            new DateTime(	2006	,	7	,	20	),
            new DateTime(	2006	,	7	,	19	),
            new DateTime(	2006	,	7	,	18	),
            new DateTime(	2006	,	7	,	17	),
            new DateTime(	2006	,	7	,	14	),
            new DateTime(	2006	,	7	,	13	),
            new DateTime(	2006	,	7	,	12	),
            new DateTime(	2006	,	7	,	11	),
            new DateTime(	2006	,	7	,	10	),
            new DateTime(	2006	,	7	,	7	),
            new DateTime(	2006	,	7	,	6	),
            new DateTime(	2006	,	7	,	5	),
            new DateTime(	2006	,	7	,	3	),
            new DateTime(	2006	,	6	,	30	),
            new DateTime(	2006	,	6	,	29	),
            new DateTime(	2006	,	6	,	28	),
            new DateTime(	2006	,	6	,	27	),
            new DateTime(	2006	,	6	,	26	),
            new DateTime(	2006	,	6	,	23	),
            new DateTime(	2006	,	6	,	22	),
            new DateTime(	2006	,	6	,	21	),
            new DateTime(	2006	,	6	,	20	),
            new DateTime(	2006	,	6	,	19	),
            new DateTime(	2006	,	6	,	16	),
            new DateTime(	2006	,	6	,	15	),
            new DateTime(	2006	,	6	,	14	),
            new DateTime(	2006	,	6	,	13	),
            new DateTime(	2006	,	6	,	12	),
            new DateTime(	2006	,	6	,	9	),
            new DateTime(	2006	,	6	,	8	),
            new DateTime(	2006	,	6	,	7	),
            new DateTime(	2006	,	6	,	6	),
            new DateTime(	2006	,	6	,	5	),
            new DateTime(	2006	,	6	,	2	),
            new DateTime(	2006	,	6	,	1	),
            new DateTime(	2006	,	5	,	31	),
            new DateTime(	2006	,	5	,	30	),
            new DateTime(	2006	,	5	,	26	),
            new DateTime(	2006	,	5	,	25	),
            new DateTime(	2006	,	5	,	24	),
            new DateTime(	2006	,	5	,	23	),
            new DateTime(	2006	,	5	,	22	),
            new DateTime(	2006	,	5	,	19	),
            new DateTime(	2006	,	5	,	18	),
            new DateTime(	2006	,	5	,	17	),
            new DateTime(	2006	,	5	,	16	),
            new DateTime(	2006	,	5	,	15	),
            new DateTime(	2006	,	5	,	12	),
            new DateTime(	2006	,	5	,	11	),
            new DateTime(	2006	,	5	,	10	),
            new DateTime(	2006	,	5	,	9	),
            new DateTime(	2006	,	5	,	8	),
            new DateTime(	2006	,	5	,	5	),
            new DateTime(	2006	,	5	,	4	),
            new DateTime(	2006	,	5	,	3	),
            new DateTime(	2006	,	5	,	2	),
            new DateTime(	2006	,	5	,	1	),
            new DateTime(	2006	,	4	,	28	),
            new DateTime(	2006	,	4	,	27	),
            new DateTime(	2006	,	4	,	26	),
            new DateTime(	2006	,	4	,	25	),
            new DateTime(	2006	,	4	,	24	),
            new DateTime(	2006	,	4	,	21	),
            new DateTime(	2006	,	4	,	20	),
            new DateTime(	2006	,	4	,	19	),
            new DateTime(	2006	,	4	,	18	),
            new DateTime(	2006	,	4	,	17	),
            new DateTime(	2006	,	4	,	13	),
            new DateTime(	2006	,	4	,	12	),
            new DateTime(	2006	,	4	,	11	),
            new DateTime(	2006	,	4	,	10	),
            new DateTime(	2006	,	4	,	7	),
            new DateTime(	2006	,	4	,	6	),
            new DateTime(	2006	,	4	,	5	),
            new DateTime(	2006	,	4	,	4	),
            new DateTime(	2006	,	4	,	3	),
            new DateTime(	2006	,	3	,	31	),
            new DateTime(	2006	,	3	,	30	),
            new DateTime(	2006	,	3	,	29	),
            new DateTime(	2006	,	3	,	28	),
            new DateTime(	2006	,	3	,	27	),
            new DateTime(	2006	,	3	,	24	),
            new DateTime(	2006	,	3	,	23	),
            new DateTime(	2006	,	3	,	22	),
            new DateTime(	2006	,	3	,	21	),
            new DateTime(	2006	,	3	,	20	),
            new DateTime(	2006	,	3	,	17	),
            new DateTime(	2006	,	3	,	16	),
            new DateTime(	2006	,	3	,	15	),
            new DateTime(	2006	,	3	,	14	),
            new DateTime(	2006	,	3	,	13	),
            new DateTime(	2006	,	3	,	10	),
            new DateTime(	2006	,	3	,	9	),
            new DateTime(	2006	,	3	,	8	),
            new DateTime(	2006	,	3	,	7	),
            new DateTime(	2006	,	3	,	6	),
            new DateTime(	2006	,	3	,	3	),
            new DateTime(	2006	,	3	,	2	),
            new DateTime(	2006	,	3	,	1	),
            new DateTime(	2006	,	2	,	28	),
            new DateTime(	2006	,	2	,	27	),
            new DateTime(	2006	,	2	,	24	),
            new DateTime(	2006	,	2	,	23	),
            new DateTime(	2006	,	2	,	22	),
            new DateTime(	2006	,	2	,	21	),
            new DateTime(	2006	,	2	,	17	),
            new DateTime(	2006	,	2	,	16	),
            new DateTime(	2006	,	2	,	15	),
            new DateTime(	2006	,	2	,	14	),
            new DateTime(	2006	,	2	,	13	),
            new DateTime(	2006	,	2	,	10	),
            new DateTime(	2006	,	2	,	9	),
            new DateTime(	2006	,	2	,	8	),
            new DateTime(	2006	,	2	,	7	),
            new DateTime(	2006	,	2	,	6	),
            new DateTime(	2006	,	2	,	3	),
            new DateTime(	2006	,	2	,	2	),
            new DateTime(	2006	,	2	,	1	),
            new DateTime(	2006	,	1	,	31	),
            new DateTime(	2006	,	1	,	30	),
            new DateTime(	2006	,	1	,	27	),
            new DateTime(	2006	,	1	,	26	),
            new DateTime(	2006	,	1	,	25	),
            new DateTime(	2006	,	1	,	24	),
            new DateTime(	2006	,	1	,	23	),
            new DateTime(	2006	,	1	,	20	),
            new DateTime(	2006	,	1	,	19	),
            new DateTime(	2006	,	1	,	18	),
            new DateTime(	2006	,	1	,	17	),
            new DateTime(	2006	,	1	,	13	),
            new DateTime(	2006	,	1	,	12	),
            new DateTime(	2006	,	1	,	11	),
            new DateTime(	2006	,	1	,	10	),
            new DateTime(	2006	,	1	,	9	),
            new DateTime(	2006	,	1	,	6	),
            new DateTime(	2006	,	1	,	5	),
            new DateTime(	2006	,	1	,	4	),
            new DateTime(	2006	,	1	,	3	),
            new DateTime(	2005	,	12	,	30	),
            new DateTime(	2005	,	12	,	29	),
            new DateTime(	2005	,	12	,	28	),
            new DateTime(	2005	,	12	,	27	),
            new DateTime(	2005	,	12	,	23	),
            new DateTime(	2005	,	12	,	22	),
            new DateTime(	2005	,	12	,	21	),
            new DateTime(	2005	,	12	,	20	),
            new DateTime(	2005	,	12	,	19	),
            new DateTime(	2005	,	12	,	16	),
            new DateTime(	2005	,	12	,	15	),
            new DateTime(	2005	,	12	,	14	),
            new DateTime(	2005	,	12	,	13	),
            new DateTime(	2005	,	12	,	12	),
            new DateTime(	2005	,	12	,	9	),
            new DateTime(	2005	,	12	,	8	),
            new DateTime(	2005	,	12	,	7	),
            new DateTime(	2005	,	12	,	6	),
            new DateTime(	2005	,	12	,	5	),
            new DateTime(	2005	,	12	,	2	),
            new DateTime(	2005	,	12	,	1	),
            new DateTime(	2005	,	11	,	30	),
            new DateTime(	2005	,	11	,	29	),
            new DateTime(	2005	,	11	,	28	),
            new DateTime(	2005	,	11	,	25	),
            new DateTime(	2005	,	11	,	23	),
            new DateTime(	2005	,	11	,	22	),
            new DateTime(	2005	,	11	,	21	),
            new DateTime(	2005	,	11	,	18	),
            new DateTime(	2005	,	11	,	17	),
            new DateTime(	2005	,	11	,	16	),
            new DateTime(	2005	,	11	,	15	),
            new DateTime(	2005	,	11	,	14	),
            new DateTime(	2005	,	11	,	11	),
            new DateTime(	2005	,	11	,	10	),
            new DateTime(	2005	,	11	,	9	),
            new DateTime(	2005	,	11	,	8	),
            new DateTime(	2005	,	11	,	7	),
            new DateTime(	2005	,	11	,	4	),
            new DateTime(	2005	,	11	,	3	),
            new DateTime(	2005	,	11	,	2	),
            new DateTime(	2005	,	11	,	1	),
            new DateTime(	2005	,	10	,	31	),
            new DateTime(	2005	,	10	,	28	),
            new DateTime(	2005	,	10	,	27	),
            new DateTime(	2005	,	10	,	26	),
            new DateTime(	2005	,	10	,	25	),
            new DateTime(	2005	,	10	,	24	),
            new DateTime(	2005	,	10	,	21	),
            new DateTime(	2005	,	10	,	20	),
            new DateTime(	2005	,	10	,	19	),
            new DateTime(	2005	,	10	,	18	),
            new DateTime(	2005	,	10	,	17	),
            new DateTime(	2005	,	10	,	14	),
            new DateTime(	2005	,	10	,	13	),
            new DateTime(	2005	,	10	,	12	),
            new DateTime(	2005	,	10	,	11	),
            new DateTime(	2005	,	10	,	10	),
            new DateTime(	2005	,	10	,	7	),
            new DateTime(	2005	,	10	,	6	),
            new DateTime(	2005	,	10	,	5	),
            new DateTime(	2005	,	10	,	4	),
            new DateTime(	2005	,	10	,	3	),
            new DateTime(	2005	,	9	,	30	),
            new DateTime(	2005	,	9	,	29	),
            new DateTime(	2005	,	9	,	28	),
            new DateTime(	2005	,	9	,	27	),
            new DateTime(	2005	,	9	,	26	),
            new DateTime(	2005	,	9	,	23	),
            new DateTime(	2005	,	9	,	22	),
            new DateTime(	2005	,	9	,	21	),
            new DateTime(	2005	,	9	,	20	),
            new DateTime(	2005	,	9	,	19	),
            new DateTime(	2005	,	9	,	16	),
            new DateTime(	2005	,	9	,	15	),
            new DateTime(	2005	,	9	,	14	),
            new DateTime(	2005	,	9	,	13	),
            new DateTime(	2005	,	9	,	12	),
            new DateTime(	2005	,	9	,	9	),
            new DateTime(	2005	,	9	,	8	),
            new DateTime(	2005	,	9	,	7	),
            new DateTime(	2005	,	9	,	6	),
            new DateTime(	2005	,	9	,	2	),
            new DateTime(	2005	,	9	,	1	),
            new DateTime(	2005	,	8	,	31	),
            new DateTime(	2005	,	8	,	30	),
            new DateTime(	2005	,	8	,	29	),
            new DateTime(	2005	,	8	,	26	),
            new DateTime(	2005	,	8	,	25	),
            new DateTime(	2005	,	8	,	24	),
            new DateTime(	2005	,	8	,	23	),
            new DateTime(	2005	,	8	,	22	),
            new DateTime(	2005	,	8	,	19	),
            new DateTime(	2005	,	8	,	18	),
            new DateTime(	2005	,	8	,	17	),
            new DateTime(	2005	,	8	,	16	),
            new DateTime(	2005	,	8	,	15	),
            new DateTime(	2005	,	8	,	12	),
            new DateTime(	2005	,	8	,	11	),
            new DateTime(	2005	,	8	,	10	),
            new DateTime(	2005	,	8	,	9	),
            new DateTime(	2005	,	8	,	8	),
            new DateTime(	2005	,	8	,	5	),
            new DateTime(	2005	,	8	,	4	),
            new DateTime(	2005	,	8	,	3	),
            new DateTime(	2005	,	8	,	2	),
            new DateTime(	2005	,	8	,	1	),
            new DateTime(	2005	,	7	,	29	),
            new DateTime(	2005	,	7	,	28	),
            new DateTime(	2005	,	7	,	27	),
            new DateTime(	2005	,	7	,	26	),
            new DateTime(	2005	,	7	,	25	),
            new DateTime(	2005	,	7	,	22	),
            new DateTime(	2005	,	7	,	21	),
            new DateTime(	2005	,	7	,	20	),
            new DateTime(	2005	,	7	,	19	),
            new DateTime(	2005	,	7	,	18	),
            new DateTime(	2005	,	7	,	15	),
            new DateTime(	2005	,	7	,	14	),
            new DateTime(	2005	,	7	,	13	),
            new DateTime(	2005	,	7	,	12	),
            new DateTime(	2005	,	7	,	11	),
            new DateTime(	2005	,	7	,	8	),
            new DateTime(	2005	,	7	,	7	),
            new DateTime(	2005	,	7	,	6	),
            new DateTime(	2005	,	7	,	5	),
            new DateTime(	2005	,	7	,	1	),
            new DateTime(	2005	,	6	,	30	),
            new DateTime(	2005	,	6	,	29	),
            new DateTime(	2005	,	6	,	28	),
            new DateTime(	2005	,	6	,	27	),
            new DateTime(	2005	,	6	,	24	),
            new DateTime(	2005	,	6	,	23	),
            new DateTime(	2005	,	6	,	22	),
            new DateTime(	2005	,	6	,	21	),
            new DateTime(	2005	,	6	,	20	),
            new DateTime(	2005	,	6	,	17	),
            new DateTime(	2005	,	6	,	16	),
            new DateTime(	2005	,	6	,	15	),
            new DateTime(	2005	,	6	,	14	),
            new DateTime(	2005	,	6	,	13	),
            new DateTime(	2005	,	6	,	10	),
            new DateTime(	2005	,	6	,	9	),
            new DateTime(	2005	,	6	,	8	),
            new DateTime(	2005	,	6	,	7	),
            new DateTime(	2005	,	6	,	6	),
            new DateTime(	2005	,	6	,	3	),
            new DateTime(	2005	,	6	,	2	),
            new DateTime(	2005	,	6	,	1	),
            new DateTime(	2005	,	5	,	31	),
            new DateTime(	2005	,	5	,	27	),
            new DateTime(	2005	,	5	,	26	),
            new DateTime(	2005	,	5	,	25	),
            new DateTime(	2005	,	5	,	24	),
            new DateTime(	2005	,	5	,	23	),
            new DateTime(	2005	,	5	,	20	),
            new DateTime(	2005	,	5	,	19	),
            new DateTime(	2005	,	5	,	18	),
            new DateTime(	2005	,	5	,	17	),
            new DateTime(	2005	,	5	,	16	),
            new DateTime(	2005	,	5	,	13	),
            new DateTime(	2005	,	5	,	12	),
            new DateTime(	2005	,	5	,	11	),
            new DateTime(	2005	,	5	,	10	),
            new DateTime(	2005	,	5	,	9	),
            new DateTime(	2005	,	5	,	6	),
            new DateTime(	2005	,	5	,	5	),
            new DateTime(	2005	,	5	,	4	),
            new DateTime(	2005	,	5	,	3	),
            new DateTime(	2005	,	5	,	2	),
            new DateTime(	2005	,	4	,	29	),
            new DateTime(	2005	,	4	,	28	),
            new DateTime(	2005	,	4	,	27	),
            new DateTime(	2005	,	4	,	26	),
            new DateTime(	2005	,	4	,	25	),
            new DateTime(	2005	,	4	,	22	),
            new DateTime(	2005	,	4	,	21	),
            new DateTime(	2005	,	4	,	20	),
            new DateTime(	2005	,	4	,	19	),
            new DateTime(	2005	,	4	,	18	),
            new DateTime(	2005	,	4	,	15	),
            new DateTime(	2005	,	4	,	14	),
            new DateTime(	2005	,	4	,	13	),
            new DateTime(	2005	,	4	,	12	),
            new DateTime(	2005	,	4	,	11	),
            new DateTime(	2005	,	4	,	8	),
            new DateTime(	2005	,	4	,	7	),
            new DateTime(	2005	,	4	,	6	),
            new DateTime(	2005	,	4	,	5	),
            new DateTime(	2005	,	4	,	4	),
            new DateTime(	2005	,	4	,	1	),
            new DateTime(	2005	,	3	,	31	),
            new DateTime(	2005	,	3	,	30	),
            new DateTime(	2005	,	3	,	29	),
            new DateTime(	2005	,	3	,	28	),
            new DateTime(	2005	,	3	,	24	),
            new DateTime(	2005	,	3	,	23	),
            new DateTime(	2005	,	3	,	22	),
            new DateTime(	2005	,	3	,	21	),
            new DateTime(	2005	,	3	,	18	),
            new DateTime(	2005	,	3	,	17	),
            new DateTime(	2005	,	3	,	16	),
            new DateTime(	2005	,	3	,	15	),
            new DateTime(	2005	,	3	,	14	),
            new DateTime(	2005	,	3	,	11	),
            new DateTime(	2005	,	3	,	10	),
            new DateTime(	2005	,	3	,	9	),
            new DateTime(	2005	,	3	,	8	),
            new DateTime(	2005	,	3	,	7	),
            new DateTime(	2005	,	3	,	4	),
            new DateTime(	2005	,	3	,	3	),
            new DateTime(	2005	,	3	,	2	),
            new DateTime(	2005	,	3	,	1	),
            new DateTime(	2005	,	2	,	28	),
            new DateTime(	2005	,	2	,	25	),
            new DateTime(	2005	,	2	,	24	),
            new DateTime(	2005	,	2	,	23	),
            new DateTime(	2005	,	2	,	22	),
            new DateTime(	2005	,	2	,	18	),
            new DateTime(	2005	,	2	,	17	),
            new DateTime(	2005	,	2	,	16	),
            new DateTime(	2005	,	2	,	15	),
            new DateTime(	2005	,	2	,	14	),
            new DateTime(	2005	,	2	,	11	),
            new DateTime(	2005	,	2	,	10	),
            new DateTime(	2005	,	2	,	9	),
            new DateTime(	2005	,	2	,	8	),
            new DateTime(	2005	,	2	,	7	),
            new DateTime(	2005	,	2	,	4	),
            new DateTime(	2005	,	2	,	3	),
            new DateTime(	2005	,	2	,	2	),
            new DateTime(	2005	,	2	,	1	),
            new DateTime(	2005	,	1	,	31	),
            new DateTime(	2005	,	1	,	28	),
            new DateTime(	2005	,	1	,	27	),
            new DateTime(	2005	,	1	,	26	),
            new DateTime(	2005	,	1	,	25	),
            new DateTime(	2005	,	1	,	24	),
            new DateTime(	2005	,	1	,	21	),
            new DateTime(	2005	,	1	,	20	),
            new DateTime(	2005	,	1	,	19	),
            new DateTime(	2005	,	1	,	18	),
            new DateTime(	2005	,	1	,	14	),
            new DateTime(	2005	,	1	,	13	),
            new DateTime(	2005	,	1	,	12	),
            new DateTime(	2005	,	1	,	11	),
            new DateTime(	2005	,	1	,	10	),
            new DateTime(	2005	,	1	,	7	),
            new DateTime(	2005	,	1	,	6	),
            new DateTime(	2005	,	1	,	5	),
            new DateTime(	2005	,	1	,	4	),
            new DateTime(	2005	,	1	,	3	),
            new DateTime(	2004	,	12	,	31	),
            new DateTime(	2004	,	12	,	30	),
            new DateTime(	2004	,	12	,	29	),
            new DateTime(	2004	,	12	,	28	),
            new DateTime(	2004	,	12	,	27	),
            new DateTime(	2004	,	12	,	23	),
            new DateTime(	2004	,	12	,	22	),
            new DateTime(	2004	,	12	,	21	),
            new DateTime(	2004	,	12	,	20	),
            new DateTime(	2004	,	12	,	17	),
            new DateTime(	2004	,	12	,	16	),
            new DateTime(	2004	,	12	,	15	),
            new DateTime(	2004	,	12	,	14	),
            new DateTime(	2004	,	12	,	13	),
            new DateTime(	2004	,	12	,	10	),
            new DateTime(	2004	,	12	,	9	),
            new DateTime(	2004	,	12	,	8	),
            new DateTime(	2004	,	12	,	7	),
            new DateTime(	2004	,	12	,	6	),
            new DateTime(	2004	,	12	,	3	),
            new DateTime(	2004	,	12	,	2	),
            new DateTime(	2004	,	12	,	1	),
            new DateTime(	2004	,	11	,	30	),
            new DateTime(	2004	,	11	,	29	),
            new DateTime(	2004	,	11	,	26	),
            new DateTime(	2004	,	11	,	24	),
            new DateTime(	2004	,	11	,	23	),
            new DateTime(	2004	,	11	,	22	),
            new DateTime(	2004	,	11	,	19	),
            new DateTime(	2004	,	11	,	18	),
            new DateTime(	2004	,	11	,	17	),
            new DateTime(	2004	,	11	,	16	),
            new DateTime(	2004	,	11	,	15	),
            new DateTime(	2004	,	11	,	12	),
            new DateTime(	2004	,	11	,	11	),
            new DateTime(	2004	,	11	,	10	),
            new DateTime(	2004	,	11	,	9	),
            new DateTime(	2004	,	11	,	8	),
            new DateTime(	2004	,	11	,	5	),
            new DateTime(	2004	,	11	,	4	),
            new DateTime(	2004	,	11	,	3	),
            new DateTime(	2004	,	11	,	2	),
            new DateTime(	2004	,	11	,	1	),
            new DateTime(	2004	,	10	,	29	),
            new DateTime(	2004	,	10	,	28	),
            new DateTime(	2004	,	10	,	27	),
            new DateTime(	2004	,	10	,	26	),
            new DateTime(	2004	,	10	,	25	),
            new DateTime(	2004	,	10	,	22	),
            new DateTime(	2004	,	10	,	21	),
            new DateTime(	2004	,	10	,	20	),
            new DateTime(	2004	,	10	,	19	),
            new DateTime(	2004	,	10	,	18	),
            new DateTime(	2004	,	10	,	15	),
            new DateTime(	2004	,	10	,	14	),
            new DateTime(	2004	,	10	,	13	),
            new DateTime(	2004	,	10	,	12	),
            new DateTime(	2004	,	10	,	11	),
            new DateTime(	2004	,	10	,	8	),
            new DateTime(	2004	,	10	,	7	),
            new DateTime(	2004	,	10	,	6	),
            new DateTime(	2004	,	10	,	5	),
            new DateTime(	2004	,	10	,	4	),
            new DateTime(	2004	,	10	,	1	),
            new DateTime(	2004	,	9	,	30	),
            new DateTime(	2004	,	9	,	29	),
            new DateTime(	2004	,	9	,	28	),
            new DateTime(	2004	,	9	,	27	),
            new DateTime(	2004	,	9	,	24	),
            new DateTime(	2004	,	9	,	23	),
            new DateTime(	2004	,	9	,	22	),
            new DateTime(	2004	,	9	,	21	),
            new DateTime(	2004	,	9	,	20	),
            new DateTime(	2004	,	9	,	17	),
            new DateTime(	2004	,	9	,	16	),
            new DateTime(	2004	,	9	,	15	),
            new DateTime(	2004	,	9	,	14	),
            new DateTime(	2004	,	9	,	13	),
            new DateTime(	2004	,	9	,	10	),
            new DateTime(	2004	,	9	,	9	),
            new DateTime(	2004	,	9	,	8	),
            new DateTime(	2004	,	9	,	7	),
            new DateTime(	2004	,	9	,	3	),
            new DateTime(	2004	,	9	,	2	),
            new DateTime(	2004	,	9	,	1	),
            new DateTime(	2004	,	8	,	31	),
            new DateTime(	2004	,	8	,	30	),
            new DateTime(	2004	,	8	,	27	),
            new DateTime(	2004	,	8	,	26	),
            new DateTime(	2004	,	8	,	25	),
            new DateTime(	2004	,	8	,	24	),
            new DateTime(	2004	,	8	,	23	),
            new DateTime(	2004	,	8	,	20	),
            new DateTime(	2004	,	8	,	19	),
            new DateTime(	2004	,	8	,	18	),
            new DateTime(	2004	,	8	,	17	),
            new DateTime(	2004	,	8	,	16	),
            new DateTime(	2004	,	8	,	13	),
            new DateTime(	2004	,	8	,	12	),
            new DateTime(	2004	,	8	,	11	),
            new DateTime(	2004	,	8	,	10	),
            new DateTime(	2004	,	8	,	9	),
            new DateTime(	2004	,	8	,	6	),
            new DateTime(	2004	,	8	,	5	),
            new DateTime(	2004	,	8	,	4	),
            new DateTime(	2004	,	8	,	3	),
            new DateTime(	2004	,	8	,	2	),
            new DateTime(	2004	,	7	,	30	),
            new DateTime(	2004	,	7	,	29	),
            new DateTime(	2004	,	7	,	28	),
            new DateTime(	2004	,	7	,	27	),
            new DateTime(	2004	,	7	,	26	),
            new DateTime(	2004	,	7	,	23	),
            new DateTime(	2004	,	7	,	22	),
            new DateTime(	2004	,	7	,	21	),
            new DateTime(	2004	,	7	,	20	),
            new DateTime(	2004	,	7	,	19	),
            new DateTime(	2004	,	7	,	16	),
            new DateTime(	2004	,	7	,	15	),
            new DateTime(	2004	,	7	,	14	),
            new DateTime(	2004	,	7	,	13	),
            new DateTime(	2004	,	7	,	12	),
            new DateTime(	2004	,	7	,	9	),
            new DateTime(	2004	,	7	,	8	),
            new DateTime(	2004	,	7	,	7	),
            new DateTime(	2004	,	7	,	6	),
            new DateTime(	2004	,	7	,	2	),
            new DateTime(	2004	,	7	,	1	),
            new DateTime(	2004	,	6	,	30	),
            new DateTime(	2004	,	6	,	29	),
            new DateTime(	2004	,	6	,	28	),
            new DateTime(	2004	,	6	,	25	),
            new DateTime(	2004	,	6	,	24	),
            new DateTime(	2004	,	6	,	23	),
            new DateTime(	2004	,	6	,	22	),
            new DateTime(	2004	,	6	,	21	),
            new DateTime(	2004	,	6	,	18	),
            new DateTime(	2004	,	6	,	17	),
            new DateTime(	2004	,	6	,	16	),
            new DateTime(	2004	,	6	,	15	),
            new DateTime(	2004	,	6	,	14	),
            new DateTime(	2004	,	6	,	10	),
            new DateTime(	2004	,	6	,	9	),
            new DateTime(	2004	,	6	,	8	),
            new DateTime(	2004	,	6	,	7	),
            new DateTime(	2004	,	6	,	4	),
            new DateTime(	2004	,	6	,	3	),
            new DateTime(	2004	,	6	,	2	),
            new DateTime(	2004	,	6	,	1	),
            new DateTime(	2004	,	5	,	28	),
            new DateTime(	2004	,	5	,	27	),
            new DateTime(	2004	,	5	,	26	),
            new DateTime(	2004	,	5	,	25	),
            new DateTime(	2004	,	5	,	24	),
            new DateTime(	2004	,	5	,	21	),
            new DateTime(	2004	,	5	,	20	),
            new DateTime(	2004	,	5	,	19	),
            new DateTime(	2004	,	5	,	18	),
            new DateTime(	2004	,	5	,	17	),
            new DateTime(	2004	,	5	,	14	),
            new DateTime(	2004	,	5	,	13	),
            new DateTime(	2004	,	5	,	12	),
            new DateTime(	2004	,	5	,	11	),
            new DateTime(	2004	,	5	,	10	),
            new DateTime(	2004	,	5	,	7	),
            new DateTime(	2004	,	5	,	6	),
            new DateTime(	2004	,	5	,	5	),
            new DateTime(	2004	,	5	,	4	),
            new DateTime(	2004	,	5	,	3	),
            new DateTime(	2004	,	4	,	30	),
            new DateTime(	2004	,	4	,	29	),
            new DateTime(	2004	,	4	,	28	),
            new DateTime(	2004	,	4	,	27	),
            new DateTime(	2004	,	4	,	26	),
            new DateTime(	2004	,	4	,	23	),
            new DateTime(	2004	,	4	,	22	),
            new DateTime(	2004	,	4	,	21	),
            new DateTime(	2004	,	4	,	20	),
            new DateTime(	2004	,	4	,	19	),
            new DateTime(	2004	,	4	,	16	),
            new DateTime(	2004	,	4	,	15	),
            new DateTime(	2004	,	4	,	14	),
            new DateTime(	2004	,	4	,	13	),
            new DateTime(	2004	,	4	,	12	),
            new DateTime(	2004	,	4	,	8	),
            new DateTime(	2004	,	4	,	7	),
            new DateTime(	2004	,	4	,	6	),
            new DateTime(	2004	,	4	,	5	),
            new DateTime(	2004	,	4	,	2	),
            new DateTime(	2004	,	4	,	1	),
            new DateTime(	2004	,	3	,	31	),
            new DateTime(	2004	,	3	,	30	),
            new DateTime(	2004	,	3	,	29	),
            new DateTime(	2004	,	3	,	26	),
            new DateTime(	2004	,	3	,	25	),
            new DateTime(	2004	,	3	,	24	),
            new DateTime(	2004	,	3	,	23	),
            new DateTime(	2004	,	3	,	22	),
            new DateTime(	2004	,	3	,	19	),
            new DateTime(	2004	,	3	,	18	),
            new DateTime(	2004	,	3	,	17	),
            new DateTime(	2004	,	3	,	16	),
            new DateTime(	2004	,	3	,	15	),
            new DateTime(	2004	,	3	,	12	),
            new DateTime(	2004	,	3	,	11	),
            new DateTime(	2004	,	3	,	10	),
            new DateTime(	2004	,	3	,	9	),
            new DateTime(	2004	,	3	,	8	),
            new DateTime(	2004	,	3	,	5	),
            new DateTime(	2004	,	3	,	4	),
            new DateTime(	2004	,	3	,	3	),
            new DateTime(	2004	,	3	,	2	),
            new DateTime(	2004	,	3	,	1	),
            new DateTime(	2004	,	2	,	27	),
            new DateTime(	2004	,	2	,	26	),
            new DateTime(	2004	,	2	,	25	),
            new DateTime(	2004	,	2	,	24	),
            new DateTime(	2004	,	2	,	23	),
            new DateTime(	2004	,	2	,	20	),
            new DateTime(	2004	,	2	,	19	),
            new DateTime(	2004	,	2	,	18	),
            new DateTime(	2004	,	2	,	17	),
            new DateTime(	2004	,	2	,	13	),
            new DateTime(	2004	,	2	,	12	),
            new DateTime(	2004	,	2	,	11	),
            new DateTime(	2004	,	2	,	10	),
            new DateTime(	2004	,	2	,	9	),
            new DateTime(	2004	,	2	,	6	),
            new DateTime(	2004	,	2	,	5	),
            new DateTime(	2004	,	2	,	4	),
            new DateTime(	2004	,	2	,	3	),
            new DateTime(	2004	,	2	,	2	),
            new DateTime(	2004	,	1	,	30	),
            new DateTime(	2004	,	1	,	29	),
            new DateTime(	2004	,	1	,	28	),
            new DateTime(	2004	,	1	,	27	),
            new DateTime(	2004	,	1	,	26	),
            new DateTime(	2004	,	1	,	23	),
            new DateTime(	2004	,	1	,	22	),
            new DateTime(	2004	,	1	,	21	),
            new DateTime(	2004	,	1	,	20	),
            new DateTime(	2004	,	1	,	16	),
            new DateTime(	2004	,	1	,	15	),
            new DateTime(	2004	,	1	,	14	),
            new DateTime(	2004	,	1	,	13	),
            new DateTime(	2004	,	1	,	12	),
            new DateTime(	2004	,	1	,	9	),
            new DateTime(	2004	,	1	,	8	),
            new DateTime(	2004	,	1	,	7	),
            new DateTime(	2004	,	1	,	6	),
            new DateTime(	2004	,	1	,	5	),
            new DateTime(	2004	,	1	,	2	),
        };

        double?[] apple_prices = new double?[] {
            91.63	,
            90.31	,
            88.6	,
            86.47	,
            85.85	,
            85.61	,
            84.05	,
            85	,
            84.35	,
            83.12	,
            83.34	,
            82.45	,
            80.51	,
            79.71	,
            78.29	,
            78.98	,
            79.16	,
            81.08	,
            80.42	,
            80.41	,
            82.19	,
            81.68	,
            81.05	,
            81.46	,
            79.95	,
            78.99	,
            74.53	,
            74.29	,
            75.4	,
            75.02	,
            75.26	,
            73.23	,
            73.81	,
            74.63	,
            74.22	,
            74.83	,
            75.38	,
            74.08	,
            74.86	,
            76.98	,
            77.01	,
            76.41	,
            77.61	,
            75.75	,
            73	,
            74.65	,
            75.26	,
            73.77	,
            73.89	,
            74.1	,
            74.17	,
            74.2	,
            72.63	,
            72.5	,
            72.52	,
            72.8	,
            70.03	,
            71.48	,
            68.38	,
            67.85	,
            66.96	,
            66.48	,
            66.98	,
            68.75	,
            67.81	,
            67.31	,
            67.62	,
            66.56	,
            67.91	,
            67.59	,
            67.98	,
            66.45	,
            63.94	,
            63.65	,
            64.07	,
            63.59	,
            64.78	,
            67.21	,
            68.3	,
            69.59	,
            68.16	,
            67.18	,
            67.96	,
            65.59	,
            63.4	,
            63.87	,
            61.93	,
            61.42	,
            60.72	,
            60.5	,
            54.1	,
            52.9	,
            52.37	,
            50.67	,
            52.25	,
            52.96	,
            55.65	,
            55	,
            55.4	,
            55.77	,
            57	,
            57.95	,
            57.27	,
            58.97	,
            56.02	,
            57.43	,
            58.99	,
            58.83	,
            59.58	,
            57.86	,
            57.47	,
            57.2	,
            57.56	,
            59.38	,
            57.61	,
            58.33	,
            57	,
            59.24	,
            60.76	,
            58.56	,
            59.72	,
            60	,
            61.66	,
            62.17	,
            59.77	,
            61.22	,
            63.55	,
            64.33	,
            63.34	,
            63.15	,
            63.38	,
            64.51	,
            63.18	,
            65.26	,
            64.98	,
            67.79	,
            67.7	,
            68.15	,
            70.6	,
            71.03	,
            71.89	,
            71.89	,
            71.13	,
            71.14	,
            71.62	,
            69.6	,
            70.39	,
            69.36	,
            68.15	,
            66.17	,
            65.75	,
            67.04	,
            67.63	,
            65.65	,
            66.22	,
            64.81	,
            66.47	,
            66.71	,
            67.99	,
            68.67	,
            69.79	,
            71.24	,
            67.21	,
            61.17	,
            62.65	,
            62.72	,
            62.75	,
            62.33	,
            58.71	,
            59.51	,
            59.96	,
            60.16	,
            61.67	,
            61.81	,
            63.99	,
            64.66	,
            64.31	,
            66.23	,
            67.32	,
            65.68	,
            63.19	,
            63.93	,
            65.66	,
            66.31	,
            65.48	,
            67.72	,
            69.61	,
            69.1	,
            68.49	,
            70.99	,
            71.46	,
            71.75	,
            71.32	,
            69.08	,
            70.29	,
            70.57	,
            69.22	,
            67.64	,
            64.71	,
            67.31	,
            64.95	,
            68.81	,
            67.6	,
            67.3	,
            71.85	,
            72.1	,
            75.42	,
            75.51	,
            75	,
            72.03	,
            72.33	,
            74.2	,
            76.04	,
            77.67	,
            76.09	,
            79.04	,
            82.49	,
            84.71	,
            85.59	,
            84.29	,
            83.9	,
            80.86	,
            76.05	,
            76.3	,
            74.38	,
            74.97	,
            74.75	,
            71.89	,
            71.45	,
            73.57	,
            74.23	,
            73.35	,
            74.02	,
            73.5	,
            72.11	,
            71.38	,
            71.11	,
            72.18	,
            72.01	,
            74.98	,
            74.91	,
            74.33	,
            74.08	,
            73.95	,
            74.05	,
            71.82	,
            72.63	,
            71.6	,
            67.82	,
            68.1	,
            69.66	,
            69.34	,
            67.11	,
            66.52	,
            64.96	,
            64.56	,
            64.52	,
            64.95	,
            62.28	,
            61.45	,
            61.54	,
            61.18	,
            60.11	,
            59.9	,
            60.23	,
            61.15	,
            61.85	,
            59.95	,
            57.5	,
            57.59	,
            54.47	,
            55.41	,
            57.03	,
            56.1	,
            56.79	,
            55.66	,
            56.14	,
            54.94	,
            52.21	,
            53.44	,
            54	,
            53.74	,
            49.25	,
            51.59	,
            50.37	,
            51.3	,
            51.7	,
            52.78	,
            53.75	,
            54.44	,
            53.61	,
            52.34	,
            51.08	,
            53.44	,
            53.84	,
            53.2	,
            51.9	,
            52.11	,
            53.19	,
            52.64	,
            51.21	,
            49.87	,
            49.61	,
            50.82	,
            51.4	,
            51.31	,
            49.78	,
            48.68	,
            48.8	,
            46.22	,
            46.26	,
            46.89	,
            46.57	,
            45.84	,
            45.74	,
            46.06	,
            45.77	,
            45.74	,
            45.87	,
            45.83	,
            46.3	,
            47.15	,
            46.25	,
            47.68	,
            46.1	,
            44	,
            43.38	,
            43.82	,
            42.65	,
            42.99	,
            42.71	,
            43.22	,
            43.19	,
            42.75	,
            42.65	,
            43.8	,
            43.99	,
            43.63	,
            43.81	,
            44	,
            43.29	,
            43.63	,
            43.19	,
            41.49	,
            41.55	,
            40.75	,
            38.35	,
            38.24	,
            38.1	,
            38.25	,
            37.63	,
            37.39	,
            37.98	,
            36.5	,
            36.81	,
            36.37	,
            37.31	,
            37.1	,
            37.76	,
            38.89	,
            38.55	,
            37.86	,
            37.61	,
            38.31	,
            37.98	,
            37.13	,
            36	,
            35.9	,
            35.81	,
            37.65	,
            36.92	,
            36.54	,
            37.92	,
            38.24	,
            40.04	,
            40.3	,
            39.76	,
            40.56	,
            40.74	,
            39.78	,
            39.7	,
            39.76	,
            37.55	,
            37.55	,
            35.84	,
            35.36	,
            35.55	,
            34.77	,
            34.13	,
            35.61	,
            36.42	,
            36.97	,
            37.24	,
            36.68	,
            37.15	,
            36.21	,
            36.43	,
            36.06	,
            35.54	,
            35.95	,
            36.19	,
            36.98	,
            35.5	,
            37.18	,
            35.51	,
            37.09	,
            35.62	,
            35.35	,
            37.26	,
            41.04	,
            42.66	,
            41.92	,
            43.74	,
            43.56	,
            42.33	,
            41.89	,
            41.09	,
            40.89	,
            41.67	,
            42.8	,
            41.75	,
            42.53	,
            42.5	,
            42.55	,
            42.83	,
            43.7	,
            42.96	,
            42.25	,
            41.18	,
            40.96	,
            40.32	,
            40.27	,
            39.83	,
            39.35	,
            40.53	,
            42.75	,
            42.81	,
            41.79	,
            44.12	,
            44.5	,
            44.86	,
            44.49	,
            44.47	,
            44.12	,
            42.65	,
            43.4	,
            43.9	,
            45.06	,
            44.21	,
            42.31	,
            40.6	,
            39.18	,
            39.37	,
            40.45	,
            39.47	,
            39.42	,
            38.9	,
            39.81	,
            38.76	,
            38.45	,
            36.99	,
            36.32	,
            36.12	,
            36.03	,
            35.38	,
            35.24	,
            35.23	,
            34.94	,
            35.33	,
            35.1	,
            34.9	,
            32.73	,
            32.28	,
            34.48	,
            34.62	,
            32.28	,
            32.25	,
            31.97	,
            31.65	,
            32.2	,
            32.4	,
            32.22	,
            32.09	,
            31.58	,
            32.01	,
            31.88	,
            31.84	,
            31.36	,
            32.49	,
            33.3	,
            32.63	,
            32.65	,
            32.46	,
            32.58	,
            32	,
            31.64	,
            31.44	,
            32.89	,
            31.34	,
            32.6	,
            33.9	,
            33.53	,
            34.22	,
            32.28	,
            32.03	,
            30.64	,
            30.67	,
            27.58	,
            27.69	,
            27.45	,
            27.47	,
            27.62	,
            27.75	,
            27.65	,
            27.38	,
            27.02	,
            27.19	,
            27.36	,
            27.23	,
            27.66	,
            26.75	,
            26.23	,
            26.2	,
            26.09	,
            25.15	,
            23.99	,
            23.77	,
            23.7	,
            23.97	,
            23.74	,
            23.71	,
            23.88	,
            22.75	,
            22.49	,
            19.88	,
            19.15	,
            19.3	,
            19.53	,
            19.81	,
            20.32	,
            19.68	,
            19.4	,
            19.33	,
            19.38	,
            19.34	,
            19.02	,
            18.76	,
            18.65	,
            18.64	,
            18.46	,
            19	,
            18.85	,
            18.57	,
            18.17	,
            17.6	,
            17.75	,
            17.8	,
            17.93	,
            17.85	,
            18.17	,
            17.88	,
            17.61	,
            17.83	,
            17.93	,
            17.25	,
            17.06	,
            17.17	,
            17.33	,
            16.52	,
            15.98	,
            15.54	,
            15.4	,
            15.35	,
            15.87	,
            15.44	,
            15.39	,
            15.42	,
            15.19	,
            15.51	,
            15.76	,
            15.15	,
            14.89	,
            15.69	,
            15.9	,
            15.65	,
            15.79	,
            16.17	,
            16.32	,
            16.14	,
            16.22	,
            15.63	,
            15.35	,
            15.84	,
            15.81	,
            16.1	,
            15.98	,
            16.1	,
            16.47	,
            14.79	,
            14.61	,
            14.57	,
            15.02	,
            15.07	,
            15.19	,
            15.48	,
            15.54	,
            16.15	,
            16.27	,
            16.25	,
            16.25	,
            16.85	,
            16.59	,
            16.85	,
            16.5	,
            16.17	,
            16.45	,
            16.41	,
            16.37	,
            15.35	,
            15.06	,
            15.37	,
            15.1	,
            15.18	,
            14.9	,
            14.39	,
            14.2	,
            14.46	,
            14.03	,
            14.03	,
            14.09	,
            14.26	,
            14.2	,
            13.67	,
            13.56	,
            13.35	,
            13.23	,
            13.53	,
            13.32	,
            13.53	,
            13.6	,
            13.65	,
            13.57	,
            13.14	,
            13.34	,
            13.29	,
            13.32	,
            13.07	,
            13.03	,
            12.89	,
            13.39	,
            13.23	,
            13.47	,
            13.56	,
            13.85	,
            13.89	,
            13.86	,
            13.86	,
            14.18	,
            14.59	,
            14.65	,
            13.32	,
            13.47	,
            14.02	,
            13.77	,
            13.65	,
            13.91	,
            14.16	,
            13.75	,
            13.56	,
            13.52	,
            13.96	,
            13.95	,
            13.52	,
            13.44	,
            12.75	,
            12.65	,
            12.93	,
            12.93	,
            12.84	,
            13.1	,
            12.91	,
            13.23	,
            13.78	,
            13.57	,
            13.84	,
            13.55	,
            13	,
            13.37	,
            12.58	,
            11.96	,
            11.9	,
            12.01	,
            11.96	,
            11.52	,
            11.4	,
            11.18	,
            11.1	,
            11.2	,
            11.23	,
            11.63	,
            11.58	,
            11.5	,
            11.86	,
            11.9	,
            11.49	,
            11.34	,
            11.35	,
            11.21	,
            10.9	,
            11.13	,
            11.16	,
            11.28	,
            11.34	,
            11.26	,
            11.53	,
            11.51	,
            11.28	,
            11.09	,
            11.31	,
            11.36	,
            11.36	,
            11.43	,
            12.1	,
            12.06	,
            11.86	,
            11.5	,
            11.68	,
            11.3	,
            11.05	,
            11.09	,
            10.64	,
        };

        double?[] apple_volume = new double?[] {
            18524200	,
            23997900	,
            22238100	,
            20385500	,
            16658000	,
            24783600	,
            23404400	,
            21034100	,
            16095500	,
            13352300	,
            32966200	,
            24675600	,
            18783300	,
            15520600	,
            15424600	,
            16624400	,
            21828300	,
            17909800	,
            17854200	,
            21248800	,
            15455600	,
            17329100	,
            16543300	,
            29732400	,
            22836200	,
            54034900	,
            40496700	,
            17175900	,
            18167600	,
            24435600	,
            21173400	,
            20423400	,
            18985300	,
            15650800	,
            16677100	,
            24424400	,
            29610100	,
            28239600	,
            25451400	,
            14493300	,
            25843200	,
            28941900	,
            39391000	,
            30678300	,
            23754000	,
            28361600	,
            29385400	,
            25358900	,
            25188500	,
            35066200	,
            28633200	,
            40933500	,
            60167400	,
            33897300	,
            31997200	,
            45284200	,
            34789400	,
            36159200	,
            14589100	,
            20524900	,
            24290800	,
            33833300	,
            26362900	,
            19427100	,
            23399700	,
            19152100	,
            20606000	,
            18793800	,
            19155500	,
            20755300	,
            27903000	,
            30762600	,
            25629300	,
            27768900	,
            24920000	,
            34137100	,
            35638000	,
            44482600	,
            66173800	,
            30037300	,
            19670300	,
            25420200	,
            31887200	,
            24696700	,
            26251600	,
            32086700	,
            21038200	,
            25816300	,
            31853300	,
            70433800	,
            49669400	,
            35730300	,
            36590800	,
            35465600	,
            44639500	,
            33118900	,
            29465100	,
            18905200	,
            28548600	,
            22614600	,
            18508600	,
            6956100	,
            26417700	,
            31192800	,
            30382300	,
            19664700	,
            16662000	,
            23578700	,
            34486900	,
            30832000	,
            24034800	,
            25163400	,
            29932200	,
            42513700	,
            31362000	,
            38594400	,
            25635200	,
            27708500	,
            49910100	,
            26803800	,
            25929900	,
            21635200	,
            24492400	,
            33661000	,
            45749200	,
            20121500	,
            15462500	,
            16549000	,
            32715400	,
            24800500	,
            25677700	,
            35209500	,
            23515800	,
            26935500	,
            33455000	,
            18899200	,
            22920500	,
            29024600	,
            16424600	,
            18988100	,
            21244700	,
            20139700	,
            30729300	,
            24535400	,
            27559400	,
            26799300	,
            27144200	,
            30212400	,
            25388800	,
            18895100	,
            25251000	,
            28178100	,
            59535100	,
            38786900	,
            28387300	,
            25783500	,
            26238500	,
            26424800	,
            33547000	,
            32268400	,
            55187100	,
            95134600	,
            79764600	,
            33283000	,
            29135400	,
            29119900	,
            49666100	,
            83815504	,
            48940100	,
            39574000	,
            38285000	,
            50993800	,
            48067700	,
            47991700	,
            21622900	,
            29001500	,
            26772800	,
            31857000	,
            22929300	,
            30756700	,
            37255100	,
            28546600	,
            23330400	,
            31174200	,
            32595200	,
            26345300	,
            22331200	,
            27279200	,
            45249300	,
            28258600	,
            19098000	,
            30604200	,
            34937100	,
            27843100	,
            20571400	,
            33863400	,
            41420400	,
            41462100	,
            31553500	,
            62874200	,
            41063000	,
            34039800	,
            49601100	,
            58991700	,
            24718700	,
            25261500	,
            18613800	,
            32626500	,
            49942900	,
            34066600	,
            42192400	,
            45563800	,
            40794800	,
            37847500	,
            40527100	,
            60566000	,
            42879900	,
            29843700	,
            27725200	,
            45743200	,
            53349800	,
            81423904	,
            24108600	,
            25159200	,
            16050800	,
            22128700	,
            28829800	,
            22295100	,
            17500900	,
            14218400	,
            21092500	,
            8209200	,
            13236100	,
            16990600	,
            17111000	,
            18903400	,
            23970400	,
            20041500	,
            51811300	,
            17636300	,
            18749800	,
            19835800	,
            28231500	,
            24266600	,
            30608200	,
            20845400	,
            31991500	,
            29031900	,
            21274100	,
            31836900	,
            36375700	,
            14107600	,
            17351900	,
            19295800	,
            18275400	,
            18748700	,
            24150200	,
            28018400	,
            19172900	,
            13211900	,
            15194600	,
            23762300	,
            19747500	,
            16920200	,
            22815400	,
            31358400	,
            31585100	,
            30609300	,
            26774500	,
            33601600	,
            27492400	,
            14697900	,
            22556900	,
            16611700	,
            21776900	,
            28454500	,
            48491500	,
            36024400	,
            21771000	,
            22029800	,
            36984000	,
            66627700	,
            96338800	,
            43781600	,
            18125200	,
            24210100	,
            27054900	,
            21813200	,
            19266400	,
            18126900	,
            18986900	,
            22744500	,
            40198000	,
            12203700	,
            19520100	,
            19944900	,
            16561700	,
            15526700	,
            29279600	,
            27990400	,
            21107300	,
            14827000	,
            16943800	,
            17603000	,
            16171300	,
            21987200	,
            25094300	,
            34395500	,
            29236400	,
            7942100	,
            12727400	,
            14391300	,
            18527200	,
            9153400	,
            9323500	,
            9866200	,
            20431100	,
            10557300	,
            13847600	,
            13448900	,
            15805700	,
            17847300	,
            19200800	,
            38811700	,
            32715600	,
            9713700	,
            12890900	,
            13601400	,
            6299400	,
            8640400	,
            9618000	,
            9225800	,
            10602700	,
            11223200	,
            20074300	,
            8975400	,
            10133900	,
            9592600	,
            10522400	,
            10753800	,
            14438000	,
            16192700	,
            23966500	,
            20939200	,
            24560100	,
            74859296	,
            24458400	,
            13822800	,
            13885300	,
            10383400	,
            13704400	,
            14093800	,
            16223900	,
            8928600	,
            14942500	,
            16012800	,
            12510700	,
            21434700	,
            14668200	,
            24080500	,
            15175900	,
            13233100	,
            11561300	,
            21290200	,
            19559800	,
            20119400	,
            12423100	,
            15563300	,
            24247600	,
            13937700	,
            14428800	,
            26616600	,
            28998800	,
            34173900	,
            13356200	,
            16207600	,
            14435900	,
            11286000	,
            18768600	,
            14143100	,
            21195000	,
            37234800	,
            16166100	,
            28327200	,
            22740100	,
            21012300	,
            16939100	,
            25096900	,
            34651500	,
            72927904	,
            15723700	,
            12703400	,
            11651700	,
            13834500	,
            16006300	,
            17740700	,
            16640000	,
            23986800	,
            20539500	,
            21924600	,
            28946700	,
            26659300	,
            29968900	,
            27128300	,
            33754700	,
            38630100	,
            47399200	,
            61717400	,
            98328304	,
            48998100	,
            35037900	,
            29345100	,
            23212500	,
            18106700	,
            14815200	,
            19865700	,
            20714800	,
            22903000	,
            22719100	,
            14105700	,
            16477000	,
            9836100	,
            12596600	,
            21779400	,
            19693400	,
            19326000	,
            33576800	,
            28640000	,
            24921900	,
            18164600	,
            21620900	,
            22601100	,
            27753900	,
            47230900	,
            36480400	,
            16094000	,
            27022100	,
            50416200	,
            16362900	,
            16721000	,
            23271800	,
            32696800	,
            54251000	,
            48042200	,
            43546200	,
            41544800	,
            54231200	,
            58544400	,
            82579200	,
            45409400	,
            42894800	,
            39036400	,
            42552000	,
            31786400	,
            18730600	,
            20127000	,
            26130400	,
            36430800	,
            24228400	,
            60039200	,
            28629000	,
            17722400	,
            26410600	,
            34615400	,
            30058200	,
            32547600	,
            32675800	,
            26853400	,
            35945000	,
            63240800	,
            113025600	,
            68560800	,
            93272400	,
            61618200	,
            79551800	,
            25198400	,
            24301200	,
            39171800	,
            24714000	,
            9949600	,
            12333600	,
            16055800	,
            21848400	,
            19981800	,
            8783200	,
            20208200	,
            38014800	,
            41718800	,
            27982000	,
            40218400	,
            14227200	,
            14847200	,
            14108600	,
            27706200	,
            26482200	,
            24710800	,
            37746400	,
            44568600	,
            44244600	,
            35265800	,
            28591200	,
            36732800	,
            61175600	,
            19648000	,
            49671000	,
            32551800	,
            91721800	,
            27331400	,
            16398200	,
            14205400	,
            10539400	,
            13430200	,
            14132200	,
            14546400	,
            18167000	,
            16991600	,
            18818600	,
            43037400	,
            33165200	,
            43006200	,
            26071000	,
            21501800	,
            28936400	,
            30866600	,
            42624800	,
            21227200	,
            14023000	,
            17252400	,
            25875200	,
            21611000	,
            28642600	,
            42884000	,
            36826000	,
            98872400	,
            41536000	,
            16435400	,
            11566800	,
            12829600	,
            15219600	,
            15939400	,
            14505800	,
            20503000	,
            16621600	,
            15179000	,
            9768200	,
            12613800	,
            14197000	,
            13196000	,
            14193000	,
            14346000	,
            13809000	,
            8750000	,
            17939600	,
            17925600	,
            8309600	,
            9100800	,
            10070600	,
            11714800	,
            16476400	,
            12268800	,
            10784200	,
            10481000	,
            14511600	,
            18418800	,
            13448600	,
            7790800	,
            13886200	,
            34137800	,
            18057800	,
            13362000	,
            9095000	,
            11313600	,
            13890000	,
            13023400	,
            11536400	,
            15559800	,
            11716000	,
            8078600	,
            11514000	,
            12537000	,
            10387400	,
            17581800	,
            8732200	,
            9874600	,
            7558200	,
            13039000	,
            8679400	,
            7934200	,
            10180400	,
            15178800	,
            14069000	,
            9770400	,
            11932800	,
            10759200	,
            11562400	,
            19041800	,
            17442200	,
            63133000	,
            29850000	,
            11292000	,
            18272200	,
            7459400	,
            8335000	,
            14214000	,
            12463600	,
            32524400	,
            12212200	,
            13323000	,
            21091200	,
            18610600	,
            11551000	,
            9018400	,
            13959600	,
            12875400	,
            13936200	,
            14509000	,
            19690000	,
            32487200	,
            15879800	,
            8713800	,
            9199200	,
            12471600	,
            14843600	,
            10567000	,
            14254000	,
            8961800	,
            11382600	,
            6504800	,
            5204200	,
            8427600	,
            11506000	,
            11427800	,
            8414400	,
            6424800	,
            7010600	,
            13414000	,
            7359400	,
            10730200	,
            9207200	,
            8209000	,
            8765000	,
            10899000	,
            8927800	,
            14965600	,
            9412800	,
            8503800	,
            9999400	,
            10629800	,
            16660800	,
            16456800	,
            8256000	,
            10138000	,
            8254600	,
            11279600	,
            12306600	,
            11638400	,
            12661400	,
            25441200	,
            14390400	,
            62908800	,
            22847600	,
            15585600	,
            8233600	,
            8604200	,
            9111400	,
            9214000	,
            13774000	,
            9802800	,
            11369000	,
            13956200	,
            12845600	,
            12526000	,
            14996200	,
            20230200	,
            15293400	,
            13768400	,
            14965400	,
            14592000	,
            11467200	,
            14694000	,
            21622600	,
            17204200	,
            11758000	,
            21280400	,
            35963000	,
            22084400	,
            18674000	,
            55021400	,
            23579400	,
            8040400	,
            9167400	,
            11488600	,
            16744200	,
            7086000	,
            9867000	,
            9252000	,
            6931400	,
            9914400	,
            11538600	,
            5058400	,
            6105600	,
            11285000	,
            6571000	,
            12448000	,
            9119400	,
            6723600	,
            6905000	,
            12601600	,
            10912600	,
            6457600	,
            10265400	,
            6617800	,
            7596400	,
            9835800	,
            10966800	,
            9688200	,
            8113200	,
            7321600	,
            8095000	,
            11283800	,
            13315000	,
            36364600	,
            22144400	,
            24250600	,
            17412400	,
            15266400	,
            16439400	,
            20959800	,
            18191000	,
            14107800	,
            5165800	,
        };

        double?[] msft_prices = new double?[] {
            29.76	,
            29.92	,
            29.92	,
            29.89	,
            29.4	,
            29.47	,
            29.12	,
            29.23	,
            29.25	,
            29.14	,
            29.16	,
            28.88	,
            28.85	,
            28.74	,
            28.63	,
            28.67	,
            28.71	,
            28.61	,
            28.43	,
            28.24	,
            28.25	,
            28.21	,
            28.18	,
            28.35	,
            28.33	,
            28.19	,
            28.42	,
            28.34	,
            28.35	,
            28.27	,
            28.12	,
            27.45	,
            27.6	,
            27.63	,
            27.78	,
            27.82	,
            27.84	,
            27.28	,
            27.27	,
            27.26	,
            27.31	,
            27.35	,
            27.11	,
            26.86	,
            26.57	,
            26.81	,
            27.09	,
            26.77	,
            26.7	,
            26.76	,
            26.24	,
            25.89	,
            25.84	,
            25.82	,
            25.51	,
            25.34	,
            25.52	,
            25.52	,
            25.75	,
            25.61	,
            25.71	,
            25.75	,
            25.86	,
            25.76	,
            25.65	,
            25.58	,
            25.53	,
            26.03	,
            25.7	,
            24.62	,
            24.62	,
            24.54	,
            24.36	,
            24.26	,
            24.29	,
            24.27	,
            24.17	,
            24.05	,
            24.12	,
            24.04	,
            24.13	,
            23.82	,
            23.89	,
            24.08	,
            23.7	,
            24.2	,
            24.05	,
            23.83	,
            23.7	,
            22.69	,
            23.23	,
            22.58	,
            22.32	,
            22.13	,
            22.1	,
            22.48	,
            22.94	,
            23.33	,
            23.14	,
            23.31	,
            23.19	,
            23.53	,
            23.14	,
            23.3	,
            23	,
            22.7	,
            22.66	,
            22.34	,
            22.72	,
            22.92	,
            22.4	,
            22.39	,
            21.94	,
            21.91	,
            21.73	,
            21.36	,
            21.56	,
            21.77	,
            21.95	,
            21.88	,
            21.97	,
            22.34	,
            22.6	,
            22.66	,
            22.49	,
            22.99	,
            23.55	,
            23.57	,
            23.33	,
            22.63	,
            22.72	,
            22.4	,
            22.67	,
            22.57	,
            22.85	,
            22.99	,
            22.92	,
            22.97	,
            23.51	,
            23.36	,
            23.47	,
            23.54	,
            23.18	,
            22.92	,
            23.75	,
            24.02	,
            23.89	,
            26.95	,
            26.8	,
            26.81	,
            26.81	,
            26.85	,
            26.73	,
            26.73	,
            26.92	,
            26.55	,
            26.77	,
            26.9	,
            26.83	,
            26.99	,
            26.95	,
            27.26	,
            27.44	,
            27.34	,
            27.26	,
            26.91	,
            26.93	,
            26.72	,
            26.61	,
            26.72	,
            26.72	,
            26.56	,
            26.85	,
            27.44	,
            27.59	,
            27.2	,
            26.97	,
            27.06	,
            26.93	,
            26.81	,
            26.87	,
            26.71	,
            26.95	,
            26.76	,
            26.62	,
            26.64	,
            26.68	,
            26.84	,
            26.58	,
            26.75	,
            26.34	,
            26.37	,
            26.43	,
            26.25	,
            26.41	,
            26.52	,
            26.59	,
            26.27	,
            26.01	,
            26.31	,
            26.28	,
            26.53	,
            26.56	,
            26.78	,
            27.15	,
            27.29	,
            27.64	,
            27.75	,
            27.6	,
            27.39	,
            26.12	,
            26.02	,
            25.91	,
            25.97	,
            26.03	,
            26.63	,
            26.45	,
            26.61	,
            26.8	,
            26.75	,
            26.9	,
            26.61	,
            26.48	,
            26.53	,
            26.61	,
            26.59	,
            26.46	,
            25.78	,
            25.9	,
            26.01	,
            26.08	,
            26.26	,
            26.21	,
            26.35	,
            26.48	,
            26.45	,
            26.52	,
            26.54	,
            26.7	,
            26.74	,
            27.06	,
            27.31	,
            27.3	,
            27.35	,
            27.3	,
            27.45	,
            27.61	,
            27.49	,
            27.29	,
            27.29	,
            27.35	,
            27.36	,
            27.52	,
            27.51	,
            27.76	,
            27.67	,
            27.57	,
            27.34	,
            27.11	,
            26.9	,
            26.81	,
            26.63	,
            26.5	,
            26.59	,
            26.55	,
            26.2	,
            25.99	,
            26.01	,
            25.51	,
            25.26	,
            25.09	,
            24.42	,
            24.68	,
            24.6	,
            24.67	,
            24.36	,
            24.37	,
            24.66	,
            24.15	,
            24.11	,
            24.25	,
            24.17	,
            23.88	,
            23.99	,
            24.04	,
            24.17	,
            24.31	,
            24.25	,
            24.55	,
            25.06	,
            25.29	,
            25.5	,
            25.23	,
            24.91	,
            24.84	,
            24.84	,
            24.91	,
            25.05	,
            25.4	,
            25.55	,
            25.62	,
            25.82	,
            25.86	,
            26.03	,
            26.15	,
            26.12	,
            26.15	,
            26.39	,
            26.54	,
            26.56	,
            26.73	,
            26.91	,
            26.71	,
            26.68	,
            26.51	,
            26.57	,
            26.35	,
            26.41	,
            26.45	,
            26.26	,
            26.36	,
            26.49	,
            26.28	,
            26.66	,
            26.51	,
            26.72	,
            26.41	,
            26.8	,
            26.59	,
            27.2	,
            26.77	,
            26.7	,
            26.27	,
            25.4	,
            25.1	,
            25.23	,
            25.2	,
            25.03	,
            25.17	,
            25.17	,
            25.91	,
            25.66	,
            25.64	,
            25.04	,
            25.27	,
            25.45	,
            25.15	,
            25.1	,
            24.78	,
            24.59	,
            24.16	,
            24.2	,
            24.48	,
            24.21	,
            24.34	,
            24.59	,
            24.57	,
            24.55	,
            24.54	,
            24.8	,
            24.57	,
            24.65	,
            24.61	,
            24.54	,
            24.54	,
            24.75	,
            24.85	,
            24.8	,
            24.92	,
            25	,
            24.89	,
            25	,
            24.86	,
            24.92	,
            25.27	,
            25.29	,
            25.28	,
            25.55	,
            25.38	,
            25.19	,
            25.23	,
            25.33	,
            25.22	,
            25.4	,
            25.18	,
            24.95	,
            24.98	,
            24.71	,
            24.42	,
            24.33	,
            24.32	,
            24.53	,
            24.64	,
            24.65	,
            24.63	,
            24.77	,
            24.65	,
            24.71	,
            23.88	,
            24.41	,
            24.19	,
            24.41	,
            24.4	,
            24.69	,
            23.76	,
            24.06	,
            24.08	,
            23.89	,
            24.27	,
            24.46	,
            24.73	,
            24.39	,
            24.36	,
            24.52	,
            24.1	,
            23.9	,
            23.67	,
            23.56	,
            23.61	,
            23.6	,
            23.37	,
            23.64	,
            23.72	,
            23.62	,
            23.43	,
            23.64	,
            23.75	,
            23.97	,
            24.06	,
            24.33	,
            24.53	,
            24.51	,
            24.84	,
            24.72	,
            24.81	,
            24.88	,
            24.59	,
            24.59	,
            24.68	,
            24.69	,
            24.58	,
            24.67	,
            24.78	,
            24.62	,
            24.65	,
            24.89	,
            25.06	,
            25.19	,
            25.33	,
            25.33	,
            25.29	,
            25.38	,
            25.39	,
            25.55	,
            25.48	,
            25.63	,
            25.5	,
            25.77	,
            25.7	,
            25.59	,
            25.5	,
            25.43	,
            25.33	,
            25.34	,
            25	,
            24.98	,
            25.18	,
            25.3	,
            25.63	,
            25.44	,
            25.58	,
            26.08	,
            26.03	,
            26.1	,
            25.97	,
            26.05	,
            26.08	,
            26.14	,
            26.04	,
            26.02	,
            26.06	,
            26.2	,
            26.25	,
            26.15	,
            26.3	,
            26.26	,
            26.36	,
            26.25	,
            26.25	,
            26.45	,
            26.4	,
            26.52	,
            26.54	,
            26.37	,
            26.52	,
            26.64	,
            26.36	,
            26.62	,
            26.52	,
            26.38	,
            26.54	,
            26.11	,
            26.07	,
            25.9	,
            25.94	,
            25.84	,
            25.95	,
            26.16	,
            26.36	,
            26.46	,
            26.41	,
            26.67	,
            26.19	,
            26.2	,
            25.98	,
            26.01	,
            25.58	,
            25.61	,
            25.34	,
            24.88	,
            24.68	,
            24.54	,
            24.44	,
            24.47	,
            24.6	,
            24.38	,
            24.14	,
            24.24	,
            24.95	,
            25.08	,
            24.62	,
            24.82	,
            24.46	,
            24.29	,
            24.49	,
            24.49	,
            24.52	,
            24.46	,
            24.61	,
            24.93	,
            24.8	,
            24.57	,
            24.68	,
            24.16	,
            24.1	,
            23.83	,
            23.76	,
            23.85	,
            23.9	,
            23.7	,
            23.82	,
            24.04	,
            24.04	,
            23.82	,
            23.76	,
            23.98	,
            23.81	,
            24.02	,
            23.84	,
            23.82	,
            23.91	,
            23.69	,
            24.13	,
            23.93	,
            23.85	,
            23.85	,
            23.99	,
            23.98	,
            24.07	,
            23.8	,
            23.8	,
            23.7	,
            23.63	,
            23.92	,
            23.57	,
            23.6	,
            23.54	,
            23.42	,
            23.88	,
            24.15	,
            23.68	,
            23.64	,
            23.98	,
            24.45	,
            24.45	,
            24.85	,
            24.82	,
            24.81	,
            24.9	,
            24.78	,
            24.97	,
            24.42	,
            25.26	,
            25.14	,
            24.67	,
            24.35	,
            23.94	,
            24.28	,
            24.51	,
            24.05	,
            24.3	,
            24.27	,
            24.08	,
            24.48	,
            24.41	,
            24.89	,
            24.94	,
            24.88	,
            24.83	,
            24.64	,
            24.89	,
            24.73	,
            24.65	,
            24.65	,
            24.7	,
            24.7	,
            24.19	,
            23.8	,
            23.88	,
            23.44	,
            23.32	,
            23.06	,
            23.17	,
            23.03	,
            22.61	,
            22.56	,
            22.76	,
            22.75	,
            22.85	,
            22.82	,
            22.77	,
            22.74	,
            22.44	,
            22.56	,
            22.42	,
            22.32	,
            22.5	,
            22.25	,
            22.53	,
            22.74	,
            22.6	,
            22.6	,
            22.59	,
            22.46	,
            22.76	,
            22.91	,
            22.94	,
            22.96	,
            22.76	,
            23.07	,
            23.14	,
            23.71	,
            23.73	,
            23.99	,
            22.61	,
            22.17	,
            22.07	,
            22.24	,
            21.92	,
            21.97	,
            22.22	,
            22.17	,
            22.31	,
            22.2	,
            22.29	,
            22.48	,
            22.61	,
            22.52	,
            21.85	,
            21.72	,
            21.95	,
            22.05	,
            21.81	,
            21.95	,
            21.27	,
            21.04	,
            21.34	,
            21.46	,
            21.68	,
            21.89	,
            21.94	,
            21.92	,
            22.11	,
            21.86	,
            22.1	,
            22.41	,
            22.5	,
            22.96	,
            22.97	,
            22.97	,
            22.99	,
            23.26	,
            23.11	,
            23.09	,
            23.26	,
            23.42	,
            23.18	,
            23.15	,
            23.05	,
            23.32	,
            23.51	,
            23.17	,
            23.48	,
            23.65	,
            23.54	,
            23.44	,
            23.59	,
            23.49	,
            23.53	,
            23.77	,
            23.87	,
            24.09	,
            24.32	,
            24.14	,
            24.61	,
            25.09	,
            24.81	,
            24.4	,
            24.65	,
            24.48	,
            24.23	,
            23.99	,
            24.13	,
            23.9	,
            24.02	,
            24.1	,
            24.53	,
            24.58	,
            24.6	,
            24.52	,
            23.91	,
        };

        double?[] msft_volume = new double?[] {
            20456700	,
            43907200	,
            66446600	,
            85703800	,
            49356700	,
            64328500	,
            63943200	,
            63012500	,
            47271800	,
            37855100	,
            89407504	,
            77403296	,
            56511200	,
            60446200	,
            41124500	,
            58674400	,
            75895904	,
            61861700	,
            47296800	,
            89060096	,
            69964200	,
            40717100	,
            61409600	,
            48525000	,
            48887800	,
            44730800	,
            40630800	,
            40122600	,
            49744800	,
            129751904	,
            120174896	,
            37219600	,
            34598500	,
            33366300	,
            36452200	,
            81967200	,
            82191200	,
            39386200	,
            52908100	,
            34283500	,
            44179700	,
            66233900	,
            54766500	,
            67903904	,
            47712500	,
            58495100	,
            71676400	,
            43039100	,
            49135000	,
            126057696	,
            74324496	,
            37706700	,
            52248800	,
            55608200	,
            36866800	,
            51266900	,
            50160400	,
            44222400	,
            31594600	,
            26380500	,
            30283100	,
            42711200	,
            34190900	,
            33115900	,
            35933300	,
            44648500	,
            89312400	,
            88398304	,
            128414800	,
            45674800	,
            52373600	,
            48994500	,
            47831900	,
            30255500	,
            31753400	,
            44405700	,
            58171300	,
            36862400	,
            45690400	,
            43155300	,
            46462000	,
            49168700	,
            40254400	,
            51705800	,
            85386800	,
            54942100	,
            60075800	,
            59586700	,
            175483808	,
            76605200	,
            82188200	,
            65047300	,
            37053500	,
            67499400	,
            73099504	,
            77379296	,
            88676304	,
            50565100	,
            63168800	,
            44775200	,
            53093500	,
            25711400	,
            73048800	,
            121395504	,
            71906496	,
            84759104	,
            53644100	,
            60532600	,
            76590600	,
            91660304	,
            90598496	,
            129640896	,
            147506496	,
            121577296	,
            86081504	,
            113175296	,
            74309696	,
            52573800	,
            104126896	,
            73827504	,
            126601296	,
            63914100	,
            73935600	,
            80230800	,
            120202000	,
            52497500	,
            46861600	,
            83052704	,
            107356704	,
            79986304	,
            87322304	,
            100071200	,
            95476400	,
            98598304	,
            82095104	,
            67314800	,
            83115904	,
            92916704	,
            76563296	,
            75345904	,
            80693504	,
            131604304	,
            171257408	,
            211527104	,
            190533504	,
            174800896	,
            591052224	,
            96509600	,
            39190000	,
            49222500	,
            42318400	,
            58528000	,
            45648300	,
            45111100	,
            56272700	,
            35796200	,
            28160000	,
            32183000	,
            42953400	,
            39432000	,
            47249400	,
            51885500	,
            41539300	,
            45470000	,
            57605300	,
            62190500	,
            54612000	,
            53150300	,
            58520500	,
            59908600	,
            69157600	,
            73682896	,
            145696096	,
            73199600	,
            67094100	,
            120615000	,
            73793696	,
            57152000	,
            39821800	,
            40342600	,
            41297200	,
            45360700	,
            57547400	,
            51613900	,
            53054100	,
            45218800	,
            41850300	,
            53061200	,
            65036100	,
            51301500	,
            44753800	,
            47359100	,
            43043100	,
            50216100	,
            41513200	,
            48868500	,
            62808900	,
            58432900	,
            46707000	,
            52127000	,
            52861700	,
            51795200	,
            72159504	,
            60170500	,
            75022704	,
            55073400	,
            68448800	,
            94841296	,
            103999200	,
            134520704	,
            69509296	,
            59072100	,
            63040700	,
            47925600	,
            79165904	,
            60367600	,
            52376200	,
            58566600	,
            41418000	,
            45994800	,
            70120704	,
            64921900	,
            55625000	,
            100963000	,
            48245500	,
            57975600	,
            79973000	,
            49044600	,
            34495500	,
            35444400	,
            37819000	,
            30689200	,
            91276896	,
            75800896	,
            62960600	,
            68680096	,
            88542496	,
            79018096	,
            65076200	,
            104285504	,
            63757200	,
            48467000	,
            63931600	,
            55583200	,
            65980000	,
            47517300	,
            42319600	,
            61006100	,
            55904700	,
            62220400	,
            57517200	,
            44082500	,
            70541296	,
            104253296	,
            65794400	,
            75431200	,
            91351000	,
            86277000	,
            65081000	,
            67152200	,
            51945600	,
            73314800	,
            59562100	,
            60091700	,
            77104800	,
            57464000	,
            73421600	,
            75067104	,
            71370400	,
            75122096	,
            106559296	,
            61566100	,
            58178100	,
            41310500	,
            51868000	,
            69431200	,
            58830600	,
            66574500	,
            69328200	,
            46924400	,
            53846700	,
            70192000	,
            71294400	,
            76567296	,
            48880900	,
            50768700	,
            81724600	,
            73684704	,
            151666304	,
            55341300	,
            57644500	,
            66807100	,
            71019400	,
            48797900	,
            56203700	,
            66396800	,
            71314896	,
            68281800	,
            61043400	,
            61832300	,
            187384304	,
            60357200	,
            54969600	,
            63422900	,
            40550500	,
            41515800	,
            52552300	,
            44656100	,
            46089000	,
            52047500	,
            75974496	,
            65210200	,
            55163200	,
            52307700	,
            36774600	,
            39306300	,
            63645000	,
            48296700	,
            41691700	,
            36043500	,
            40861900	,
            52413100	,
            46894600	,
            45976600	,
            52006500	,
            48646800	,
            62818800	,
            64761800	,
            77207200	,
            82212400	,
            91461400	,
            139422400	,
            137510096	,
            61346800	,
            59524400	,
            44738700	,
            57977300	,
            51476400	,
            45174600	,
            97558896	,
            112932096	,
            71424800	,
            113290096	,
            39668000	,
            56472800	,
            69506800	,
            44749200	,
            63384800	,
            61525400	,
            56104000	,
            80082896	,
            64214600	,
            61883500	,
            69718400	,
            82018200	,
            55859900	,
            53058100	,
            61636200	,
            57970700	,
            105159800	,
            60492700	,
            81084000	,
            50538900	,
            90821296	,
            65918800	,
            50764800	,
            44243300	,
            49104100	,
            39459800	,
            52767900	,
            45369700	,
            54511400	,
            40756900	,
            79659504	,
            27212500	,
            54621000	,
            46131100	,
            54978000	,
            50579200	,
            35749000	,
            61287700	,
            75421104	,
            64444500	,
            52120800	,
            71182400	,
            39983200	,
            50577300	,
            77204304	,
            74540704	,
            59463300	,
            62235100	,
            61872400	,
            64322600	,
            59362300	,
            86864200	,
            67867800	,
            54376700	,
            98641200	,
            83623104	,
            47732800	,
            60464300	,
            75457904	,
            80087504	,
            93562304	,
            91923504	,
            65956200	,
            75766400	,
            100251600	,
            66754400	,
            60929300	,
            67517800	,
            47791800	,
            47956300	,
            77451504	,
            78020200	,
            73549600	,
            62196400	,
            64619600	,
            62382300	,
            59585700	,
            74231696	,
            49802000	,
            78820896	,
            79293296	,
            102113296	,
            71446200	,
            135904000	,
            60573200	,
            74841400	,
            71469400	,
            65550500	,
            60617900	,
            59132900	,
            62991800	,
            52871800	,
            80407400	,
            63058200	,
            52183600	,
            67739000	,
            56394800	,
            82728000	,
            62467700	,
            85236304	,
            83689400	,
            96419200	,
            77091104	,
            67024800	,
            57506600	,
            76551600	,
            58694000	,
            83835904	,
            71796400	,
            77874800	,
            61343700	,
            57763400	,
            61246500	,
            62545400	,
            79329504	,
            57981700	,
            71442096	,
            110466496	,
            93204096	,
            64974500	,
            67580704	,
            69010896	,
            76501000	,
            58380100	,
            58114100	,
            69146400	,
            92180800	,
            89861600	,
            72940600	,
            64712000	,
            70376600	,
            68723296	,
            76890496	,
            72463504	,
            109442096	,
            65002900	,
            54959500	,
            48355400	,
            47594900	,
            55075900	,
            55958500	,
            65801900	,
            63651900	,
            94646096	,
            85552800	,
            126184400	,
            88997504	,
            106303904	,
            127843200	,
            93812496	,
            70949200	,
            83006000	,
            95655000	,
            111656000	,
            55297400	,
            76498400	,
            96088304	,
            99889000	,
            75960400	,
            67079900	,
            24398700	,
            60069200	,
            70459696	,
            92410800	,
            85808600	,
            63249900	,
            58830700	,
            64522600	,
            104468000	,
            162268992	,
            87358896	,
            84097696	,
            100401000	,
            112802096	,
            95337696	,
            87867696	,
            79666704	,
            89417104	,
            72930896	,
            80010096	,
            63059600	,
            72392600	,
            76966600	,
            61529500	,
            101912800	,
            94988496	,
            69078096	,
            57026500	,
            50350700	,
            49828500	,
            41548700	,
            49500700	,
            56412900	,
            44691000	,
            49556600	,
            38401500	,
            56999600	,
            58017700	,
            62016200	,
            66302800	,
            71218000	,
            61529300	,
            62055100	,
            47813600	,
            49859800	,
            52155800	,
            68409000	,
            73874400	,
            51513600	,
            65283000	,
            35951500	,
            52605700	,
            55920000	,
            48239200	,
            52664500	,
            56904700	,
            53278100	,
            44893400	,
            46174400	,
            42161700	,
            48507500	,
            52106700	,
            36679600	,
            33248700	,
            35465500	,
            53512700	,
            40835300	,
            39572200	,
            46494800	,
            46293000	,
            58844000	,
            56879700	,
            54347200	,
            43333200	,
            50279700	,
            53097300	,
            57632700	,
            51877500	,
            75628000	,
            55591700	,
            46217900	,
            53990900	,
            52267000	,
            59552900	,
            60148400	,
            62718800	,
            72968400	,
            72387600	,
            97372704	,
            124640704	,
            201518000	,
            89010704	,
            60354500	,
            66406300	,
            46759700	,
            87656304	,
            43274100	,
            45757300	,
            50249300	,
            59125100	,
            66255700	,
            69158896	,
            36690100	,
            78441400	,
            83544400	,
            55371700	,
            77024096	,
            71136496	,
            65503800	,
            58558400	,
            98932000	,
            116881696	,
            134218704	,
            105427504	,
            67431104	,
            114183400	,
            67377504	,
            48109200	,
            50385500	,
            58447700	,
            65218600	,
            48815300	,
            45933100	,
            54020000	,
            48369500	,
            37393000	,
            49071900	,
            50306900	,
            66615000	,
            56250500	,
            57809300	,
            52089900	,
            60052800	,
            58158600	,
            55149600	,
            43775300	,
            63861500	,
            64145600	,
            57917200	,
            64621400	,
            68290200	,
            62693900	,
            51841700	,
            55496400	,
            65916200	,
            66172200	,
            77787296	,
            72842200	,
            80716800	,
            89391000	,
            258268992	,
            99207696	,
            49252000	,
            59902600	,
            44592100	,
            51768600	,
            73756896	,
            61079600	,
            56971500	,
            38786800	,
            45294600	,
            63268900	,
            48992000	,
            53800300	,
            98043800	,
            69051904	,
            70533200	,
            59010400	,
            51881600	,
            61584900	,
            85677904	,
            97584704	,
            91696304	,
            127605200	,
            86281600	,
            123231000	,
            56241400	,
            65453800	,
            68835296	,
            64137100	,
            90536304	,
            75155800	,
            81111696	,
            69367800	,
            59849800	,
            44023200	,
            54998700	,
            66331000	,
            51912300	,
            58266500	,
            66602700	,
            64275700	,
            55426500	,
            50256800	,
            57821900	,
            61840600	,
            50334700	,
            43477000	,
            67541104	,
            44537000	,
            51515300	,
            37790600	,
            48108500	,
            47209600	,
            55527500	,
            60648000	,
            47993800	,
            62891800	,
            40528700	,
            63748400	,
            71336000	,
            63196200	,
            58299600	,
            127259104	,
            78425200	,
            53570600	,
            63068500	,
            63983400	,
            58504100	,
            43907000	,
            51555900	,
            55845200	,
            67079900	,
            58810800	,
            54298200	,
            46950800	,
            67333696	,
            44487700	,
        };
    }
}